@@ -1,5 +1,5 @@
 
-# $Id: ES.pm,v 2.103 2010-03-31 03:36:55 Martin Exp $
+# $Id: ES.pm,v 2.104 2013-03-03 15:03:57 Martin Exp $
 
 =head1 NAME
 
@@ -32,18 +32,12 @@ use warnings;
 use Carp;
 use base 'WWW::Search::Ebay';
 our
-$VERSION = do { my @r = (q$Revision: 2.103 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.104 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 sub _native_setup_search
   {
   my ($self, $native_query, $rhOptsArg) = @_;
-  $rhOptsArg ||= {};
-  unless (ref($rhOptsArg) eq 'HASH')
-    {
-    carp " --- second argument to _native_setup_search should be hashref, not arrayref";
-    return undef;
-    } # unless
-  $rhOptsArg->{search_host} = 'http://search.ebay.es';
+  $self->{search_host} = 'http://www.ebay.es';
   return $self->SUPER::_native_setup_search($native_query, $rhOptsArg);
   } # _native_setup_search
 
@@ -101,6 +95,7 @@ sub _process_date_abbrevs
   {
   my $self = shift;
   my $s = shift;
+  $s =~ s!Tiempo\s+restante:!!gi;
   # Convert Spanish abbreviations for units of time to something
   # Date::Manip can parse (namely, English words):
   $s =~ s!(\d)d!$1 days!;
